@@ -32,6 +32,9 @@ OC.L10N.register(
     "- You can now search for chats and messages in the unified search in the top bar" : "- You can now search for chats and messages in the unified search in the top bar",
     "- Spice up your messages with emojis from the emoji picker" : "- Spice up your messages with emojis from the emoji picker",
     "- You can now change your camera and microphone while being in a call" : "- You can now change your camera and microphone while being in a call",
+    "- Raise your hand in a call with the R key" : "- Raise your hand in a call with the R key",
+    "- Join the same conversation and call from multiple devices" : "- Join the same conversation and call from multiple devices",
+    "- Send voice messages, share your location or contact details" : "- Send voice messages and share your location or contact details",
     "There are currently no commands available." : "There are currently no commands available.",
     "The command does not exist" : "The command does not exist",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "An error occurred while running the command. Please ask an administrator to check the logs.",
@@ -39,6 +42,10 @@ OC.L10N.register(
     "{actor} created the conversation" : "{actor} created the conversation",
     "You created the conversation" : "You created the conversation",
     "An administrator created the conversation" : "An administrator created the conversation",
+    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"",
+    "{actor} set the description" : "{actor} set the description",
+    "You set the description" : "You set the description",
+    "An administrator set the description" : "An administrator set the description",
     "Talk to %s" : "Talk to %s",
     "{user} mentioned you in a private conversation" : "{user} mentioned you in a private conversation",
     "{user} invited you to a private conversation" : "{user} invited you to a private conversation",
@@ -120,7 +127,6 @@ OC.L10N.register(
     "Password protect" : "Password protect",
     "Close" : "Close",
     "Conversation name" : "Conversation name",
-    "Camera" : "Camera",
     "Reply" : "Reply",
     "Today" : "Today",
     "Yesterday" : "Yesterday",
@@ -170,6 +176,7 @@ OC.L10N.register(
     "Unmute audio (m)" : "Unmute audio (m)",
     "Disable video (v)" : "Disable video (v)",
     "Enable video (v)" : "Enable video (v)",
+    "Camera" : "Camera",
     "Remove" : "Remove",
     "Enabled" : "Enabled",
     "Share link" : "Share link",
