@@ -126,10 +126,10 @@ OC.L10N.register(
     "Unmute audio (m)" : "Habilitar audio (m)",
     "Disable video (v)" : "Deshabilitar video (v)",
     "Enable video (v)" : "Habilitar video (v)",
+    "Remove" : "Eliminar",
+    "Enabled" : "Habilitado",
     "Share link" : "Compartir liga",
     "Exit fullscreen (f)" : "Salir de pantalla completa (f)",
-    "Fullscreen (f)" : "Pantalla completa (f)",
-    "Remove" : "Eliminar",
-    "Enabled" : "Habilitado"
+    "Fullscreen (f)" : "Pantalla completa (f)"
 },
 "nplurals=2; plural=(n != 1);");
