@@ -12,6 +12,7 @@ OC.L10N.register(
     "_%n other_::_%n others_" : ["%n autre","%n autres"],
     "{actor} invited you to {call}" : "{actor} vos a convidat a {call}",
     "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Sètz convidat a una <strong>conversacion</strong> o avètz agut una <strong>sonada</strong>",
+    "Other activities" : "Autras activitats",
     "Talk" : "Talk",
     "Guest" : "Convidat",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "La benvenguda a Nextcloud Talk !\nDins aquesta conversacion vos informarem a prepaus de las foncionalitats novèlas dins Nextcloud Talk.",
@@ -103,6 +104,7 @@ OC.L10N.register(
     "An administrator removed circle {circle}" : "Un administrator tirèt lo cercle {circle}",
     "{actor} shared a file which is no longer available" : "{actor} partegèt un fichièr qu’es pas pus disponible",
     "You shared a file which is no longer available" : "Partegèretz un fichièr qu'es pas pus disponible",
+    "The shared location is malformed" : "L’emplaçament partejat es mal format",
     "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} configurèt Matterbridge per sincronizar aquesta conversacion amb d’autras discussions",
     "You set up Matterbridge to synchronize this conversation with other chats" : "Avètz configurat Matterbridge per sincronizar aquesta conversacion amb d’autras discussions",
     "{actor} updated the Matterbridge configuration" : "{actor} actualizèt la configuracion Matterbridge",
@@ -120,6 +122,7 @@ OC.L10N.register(
     "Message deleted by author" : "Messatge suprimit per son autor",
     "Message deleted by {actor}" : "Messatge suprimit per {actor}",
     "Message deleted by you" : "Messatge suprimit per vos",
+    "Deleted user" : "Utilizaire suprimit",
     "%s (guest)" : "%s (convidat)",
     "You missed a call from {user}" : "Avètz mancat una sonada de {user}",
     "You tried to call {user}" : "Avètz ensajat de sonar {user}",
@@ -562,11 +565,9 @@ OC.L10N.register(
     "Enable screensharing" : "Activar lo partiment d’ecran",
     "Bad sent video and screen quality." : "Marrida vidèo enviada e qualitat d’ecran.",
     "Bad sent screen quality." : "Marrida qualitat d’ecran enviada.",
-    "Your internet connection or computer are busy and other participants might be unable to see you. To improve the situation try to disable your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo pendent un partiment d’ecran.",
     "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vejan pas vòstre ecran.",
     "Your internet connection or computer are busy and other participants might be unable to see you." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas.",
     "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo pendent un partiment d’ecran.",
-    "Your internet connection or computer are busy and other participants might be unable to understand and see your screen. To improve the situation try to disable your screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar lo partiment d’ecran.",
     "Disable screenshare" : "Desactivar lo partiment d’ecran",
     "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo.",
     "Your internet connection or computer are busy and other participants might be unable to understand you." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas.",
@@ -597,6 +598,8 @@ OC.L10N.register(
     "Description" : "Descripcion",
     "Enter a description for this conversation" : "Picatz una descripcion per aquesta conversacion",
     "Chat notifications" : "Notificacions de chat",
+    "Device check" : "Verificacion de periferic",
+    "Always show the device preview screen before joining a call in this conversation." : "Totjorn mostrar l’ecran d’apercebut abans de rejónher una sonada d’aquesta conversacion.",
     "Guests access" : "Accès convidat",
     "Meeting settings" : "Paramètres de reünion",
     "Matterbridge" : "Matterbridge",
@@ -703,6 +706,9 @@ OC.L10N.register(
     "Cancel editing description" : "Anullar la modificacion de la descripcion",
     "Submit conversation description" : "Enviar la descripcion de la conversacion",
     "Edit conversation description" : "Editar la descripcion de la conversacion",
+    "Camera and microphone check" : "Verificacion de camèra e de microfòn",
+    "Choose devices" : "Causir periferics",
+    "Always show this dialog before joining a call in this conversation." : "Totjorn mostrar aquesta fenèstra abans de rejónher una sonada d’aquesta conversacion.",
     "Mark as read" : "Marcar coma legit",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
@@ -739,13 +745,6 @@ OC.L10N.register(
     "You are currently waiting in the lobby" : "Sètz a esperar dins la sala d’espèra",
     "The meeting will start soon" : "La conferéncia començarà lèu",
     "This meeting is scheduled for {startTime}" : "La conferéncia es planificada per {startTime}",
-    "Calls are not supported in your browser" : "Vòstre navegador pren pas encarga las sonadas",
-    "Access to microphone is only possible with HTTPS" : "L’accès al microfòn es sonque possibla amb HTTPS",
-    "Access to microphone was denied" : "L’accès al microfòn es estat refusat",
-    "Error while accessing microphone" : "Error pendent l’accès al microfòn",
-    "Access to camera is only possible with HTTPS" : "L’accès a la camèra es sonque possibla amb HTTPS",
-    "Microphone" : "Microfòn",
-    "Camera" : "Camèra",
     "No microphone available" : "Cap de microfòn pas disponible",
     "Select microphone" : "Causir microfòn",
     "No camera available" : "Cap de camèra pas disponibla",
@@ -759,6 +758,7 @@ OC.L10N.register(
     "Unread messages" : "Messatges pas legits",
     "Sending message" : "Mandadís del messatge",
     "Message sent" : "Messatge mandat",
+    "Message read by everyone who shares their reading status" : "Messatge legit per tot lo monde que partejan lo estatut de lectura",
     "Not enough free space to upload file" : "Pas pro d’espaci liure per enviar lo fichièr",
     "You are not allowed to share files" : "Avètz pas lo drech de partejar de fichièrs",
     "You cannot send messages to this conversation at the moment" : "Podètz pas enviar de messatges a aquesta conversacion pel moment",
@@ -776,6 +776,7 @@ OC.L10N.register(
     "Go to conversation" : "Anar a la conversacion",
     "Choose a conversation to forward the selected message." : "Causir una conversacion destinària del messatge seleccionat.",
     "Error while forwarding message" : "Error en transferissent lo messatge",
+    "Open this location in OpenStreetMap" : "Dobrir aquesta posicion dins OpenStreetMap",
     "Scroll to bottom" : "Desfilar enbàs",
     "Today" : "Uèi",
     "Yesterday" : "Ièr",
@@ -814,9 +815,13 @@ OC.L10N.register(
     "Add users" : "Apondre utilizaires",
     "Add groups" : "Apondre grops",
     "Add emails" : "Apondre emails",
+    "Add circles" : "Apondre cercles",
     "Searching …" : "Recèrca…",
     "No results" : "Pas cap de resultat",
+    "Add users, groups or circles" : "Apondre utilizaires, grops o cercles",
     "Add users or groups" : "Add users or groups",
+    "Add users or circles" : "Apondre utilizaires o cercles",
+    "Add groups or circles" : "Apondre grops o cercles",
     "Add other sources" : "Apondre d'autras fonts",
     "Participants" : "Participants",
     "Search or add participants" : "Cercar o apondre participants",
@@ -827,7 +832,6 @@ OC.L10N.register(
     "Meeting ID: {meetingId}" : "ID reünion : {meetingId}",
     "Your PIN: {attendeePin}" : "Vòstre PIN : {attendeePin}",
     "Display name: " : "Nom d’afichatge :",
-    "Choose devices" : "Causir periferics",
     "Attachments folder" : "Dossièr de pèças-juntas",
     "Privacy" : "Confidencialitat",
     "Sounds" : "Sons",
@@ -880,6 +884,11 @@ OC.L10N.register(
     "Post to a conversation" : "Publicar dins una conversacion",
     "Post to conversation" : "Publicar a la conversacion",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
+    "Calls are not supported in your browser" : "Vòstre navegador pren pas encarga las sonadas",
+    "Access to microphone is only possible with HTTPS" : "L’accès al microfòn es sonque possibla amb HTTPS",
+    "Access to microphone was denied" : "L’accès al microfòn es estat refusat",
+    "Error while accessing microphone" : "Error pendent l’accès al microfòn",
+    "Access to camera is only possible with HTTPS" : "L’accès a la camèra es sonque possibla amb HTTPS",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk foguèt mes a jorn, mercés de tornar cargar la pagina",
     "Do not disturb" : "Me desrengar pas",
     "Away" : "Absent",
@@ -932,10 +941,14 @@ OC.L10N.register(
     "Unmute audio (m)" : "Restablir lo son (m)",
     "Disable video (v)" : "Desactivar la vidèo (v)",
     "Enable video (v)" : "Activar la vidèo (v)",
+    "Your internet connection or computer are busy and other participants might be unable to see you. To improve the situation try to disable your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo pendent un partiment d’ecran.",
+    "Your internet connection or computer are busy and other participants might be unable to understand and see your screen. To improve the situation try to disable your screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar lo partiment d’ecran.",
     "This conversation is read only" : "La conversacion es en lectura sola",
     "Conversation, " : "Conversacion, ",
     "Allow guests to join via link " : "Permetre als convidats de rejónher via ligam",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Sètz a esperar dins la sala d’espèra. Aquesta conferéncia es planificada per {startTime}",
+    "Microphone" : "Microfòn",
+    "Camera" : "Camèra",
     "Remove" : "Suprimir",
     "[Unknown username]" : "[utilizaire desconegut]",
     "More info on Matterbridge." : "Mai d‘informacions sus Matterbridge.",
@@ -961,7 +974,6 @@ OC.L10N.register(
     "Conversation \"{conversationName}\"" : "Conversacion « {conversationName} »",
     "Settings for conversation \"{conversationName}\"" : "Paramètres per la conversacion « {conversationName} »",
     "You can not send messages to this conversation at the moment" : "Podètz pas enviar de messatges a aquesta conversacion pel moment",
-    "Add a description for this conversation" : "Apondètz una descripcion per aquesta conversacion",
-    "Open this location in Openstreetmap" : "Dobrir aqueste lòc dins Openstreetmap"
+    "Add a description for this conversation" : "Apondètz una descripcion per aquesta conversacion"
 },
 "nplurals=2; plural=(n > 1);");
