@@ -48,7 +48,7 @@ class ListCommand extends Base {
 			->setDescription('List TURN servers.');
 	}
 
-	protected function execute(InputInterface $input, OutputInterface $output): ?int {
+	protected function execute(InputInterface $input, OutputInterface $output): int {
 		$config = $this->config->getAppValue('spreed', 'turn_servers');
 		$servers = json_decode($config, true);
 		if (!is_array($servers)) {
